PROGRAM test_mat_mult
!
!  Purpose:
!    To test the version of subroutine mat_mult with an 
!    explicit interface. 
!
!  Record of revisions:
!       Date       Programmer         Description of change
!       ====       ==========         =====================
!    05/12/2016    S. J. Chapman      Original code
!
USE subs
IMPLICIT NONE

! List of named constants:
INTEGER, PARAMETER :: MAXSIZ = 20    ! Maximum array size

! List of variables:
REAL,DIMENSION(MAXSIZ,MAXSIZ) :: a   ! Array A
REAL,DIMENSION(MAXSIZ,MAXSIZ) :: b   ! Array B
REAL,DIMENSION(MAXSIZ,MAXSIZ) :: c   ! Array C
INTEGER :: error                     ! Error flag
CHARACTER(len=30) :: filename1       ! Name of file containing A
CHARACTER(len=30) :: filename2       ! Name of file containing B
INTEGER :: i, j                      ! Loop index
INTEGER :: istat1                    ! I/o status
INTEGER :: istat2                    ! I/o status
CHARACTER(len=80) :: msg1            ! Error message
CHARACTER(len=80) :: msg2            ! Error message
INTEGER :: ncol1                     ! no. of cols used in A
INTEGER :: ncol2                     ! no. of cols used in B
INTEGER :: nrow1                     ! no. of rows used in A
INTEGER :: nrow2                     ! no. of rows used in B

! Get the name of the disk file containing array A.
WRITE (*,1000) 
1000 FORMAT ('Enter the file name containing array A: ')
READ (*,'(A30)') filename1

! Get the name of the disk file containing array B.
WRITE (*,1010) 
1010 FORMAT ('Enter the file name containing array B: ')
READ (*,'(A30)') filename2
 
! Open input data files.  Status is OLD because the input data 
! must already exist.
OPEN (UNIT=1, FILE=filename1, STATUS='OLD', ACTION='READ', &
      IOSTAT=istat1, IOMSG=msg1 )
OPEN (UNIT=2, FILE=filename2, STATUS='OLD', ACTION='READ', &
      IOSTAT=istat2, IOMSG=msg2 )
 
! Were the OPENs successful? 
IF ( (istat1 == 0) .AND. (istat2 == 0) ) THEN
 
   ! The files were opened successfully.  Read the size of array A.
   READ (1,*) nrow1, ncol1
 
   ! Read the size of array B.
   READ (2,*) nrow2, ncol2
 
   ! If any dimension exceeds MAXSIZ, tell user and quit.
   IF ( (nrow1 > MAXSIZ) .OR. (ncol1  >  MAXSIZ) .OR. &
        (nrow2 > MAXSIZ) .OR. (ncol2  >  MAXSIZ) ) THEN
 
      ! Error.
      WRITE (*,1020) MAXSIZ
      1020 FORMAT ('Error--An array dimension exceeds max size:',I6)
 
   ELSE
 
      ! Read matrices A and B.
      DO i = 1, nrow1
          READ (1,*) (a(i,j), j=1,ncol1)
      END DO
      DO i = 1, nrow2
         READ (2,*) (b(i,j), j=1,ncol2)
      END DO
 
      ! Multiply matrices
      CALL mat_mult ( a, b, c, error )
 
      ! Write out the result.
      IF ( error == 0 ) THEN 
         WRITE (*,*) 'The resulting matrix C = A * B is:'
         DO i = 1, nrow1
            WRITE (*,1030) (c(i,j), j=1,ncol2)
            1030 FORMAT (1X,8(F9.2,1X))
         END DO
  
      ELSE
 
         WRITE (*,1040) error
         1040 FORMAT ('ERROR--Subroutine error', I6)

      END IF

   END IF
 
   ! Close files
   CLOSE (UNIT=1)
   CLOSE (UNIT=2)  
 
ELSE
 
   ! If we get here, there was an error opening one of the files.
   ! Tell user, and quit.
   IF ( istat1 /= 0 ) THEN
      WRITE (*,1050) filename1, istat1
      1050 FORMAT (' Error opening file ',A,': IOSTAT = ',I6)
      WRITE (*,'(A)') msg1
   END IF
   IF ( istat2 /= 0 ) THEN
      WRITE (*,1050) filename2, istat2
      WRITE (*,'(A)') msg2
   END IF
END IF

END PROGRAM test_mat_mult

